@@ -1,4 +1,5 @@
 #include <QtGui/QApplication>
+#include <QtGui>
 #include "mainwindow.h"
 
 
@@ -68,6 +69,32 @@ int main(int argc, char *argv[])
 
 
     MainWindow w;
+
+
+
+
+
+    QSettings oSettings("janbergmann", "simplenotewidget");
+    QColor cldefault = oSettings.value("bgcolor", QColor(255,255,0)).value<QColor>();
+
+
+    int bgcoloralpha = oSettings.value("bgcoloralpha", int(200)).toInt();
+    cldefault.setAlpha(bgcoloralpha);
+
+    //QColor cldefault = QColor(255,255,0);
+    //cldefault.setAlpha(200);
+
+
+    QPalette pal = w.palette();
+    w.setAttribute(Qt::WA_TranslucentBackground);
+    w.setAttribute(Qt::WA_NoSystemBackground, false);
+
+    pal.setColor(QPalette::Window, cldefault);
+    w.setPalette(pal);
+    w.ensurePolished(); // workaround Oxygen filling the background
+    w.setAttribute(Qt::WA_StyledBackground, false);
+
+
     w.resize(300, 180);
     w.show();
     return app.exec();
