@@ -1,8 +1,8 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 #include "dialog.h"
-#include <QFile>
-#include <QXmlStreamWriter>
+#include "settingsdlg.h"
+
 #include <QDateTime>
 #include <QMessageBox>
 #include <qinputdialog.h>
@@ -11,11 +11,13 @@
 #include <QPaintEvent>
 #include <QByteArray>
 #include <QCoreApplication>
-#include <QDir>
 #include <QPainter>
 #include <QPaintEvent>
 #include <QMovie>
 #include <QDialog>
+#include <QSettings>
+
+
 
 #ifdef Q_WS_HILDON
     #include <X11/Xlib.h>
@@ -25,69 +27,11 @@
 
 
 
-QString GetDataFile()
-{
-#ifdef Q_WS_HILDON
-    QString sPath = QDir::homePath() + QLatin1String("/MyDocs/.simplenotewidget/");
-    QString filename =sPath + "simplenotewidget.xml";
-    QDir dir;
-    dir.mkpath(sPath);
-#else
-    QString filename = QApplication::applicationDirPath()  + "/simplenotewidget.xml";
-#endif
-    return   filename;
-}
 
 
 
 
 
-
-void MainWindow::LoadItems()
-{
-     QString filename = GetDataFile();
-     QFile file(filename);
-     file.open(QIODevice::ReadOnly );
-     QXmlStreamReader Rxml(&file);
-     Rxml.setDevice(&file);
-     Rxml.readNext();
-     while(!Rxml.atEnd())
-     {
-         if(Rxml.isStartElement())
-                 {
-
-                     if(Rxml.name() == "simplenotewidget")
-                     {
-                           Rxml.readNext();
-                     }
-                     else if(Rxml.name() == "noteelement")
-                     {
-                         QXmlStreamAttributes attributes = Rxml.attributes();
-                         //QString sNodeText = attributes.value("note").toString();
-                         //QString sNodeDate =  attributes.value("notedate").toString();
-
-                         ui->teMain->setText(attributes.value("note").toString());
-                         ui->lblDate->setText(attributes.value("notedate").toString());
-                         Rxml.readNext();
-                     }
-
-                     else
-                     {
-                       Rxml.raiseError(QObject::tr("Not a simplenotewidget file"));
-                         Rxml.readNext();
-                     }
-                 }
-                         else
-                         {
-                                 Rxml.readNext();
-                         }
-
-}
-file.close();
-}
-
-
-
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(0, Qt::FramelessWindowHint),
     ui(new Ui::MainWindow)
@@ -118,16 +62,69 @@ MainWindow::MainWindow(QWidget *parent) :
 #endif
     ui->setupUi(this);
 
-    this->setAutoFillBackground(false);
 
 
-    //QColor cldefault(250,235,146);
-    QColor cldefault(255,255,0);
-    QColor cltextedit(0,0,0);
-    QColor cllabelcolor(0,0,0);
 
-    this->setPalette(QPalette(cldefault));
-    this->setAutoFillBackground(true);
+
+   SetupThisUi();
+
+
+
+}
+
+
+
+
+
+
+
+#ifdef Q_WS_HILDON
+    //Filter show setting requests
+    bool MainWindow::x11Event ( XEvent * event )
+    {
+        static Atom appletShowSettingAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_SHOW_SETTINGS", false);
+        if (event->xclient.message_type == appletShowSettingAtom )
+        {
+          //QMessageBox::information(0, "Settings", "will implement this in a future release", QMessageBox::Ok);
+
+            settingsdlg w(0);
+            w.setProperty("FingerScrollable", true);
+            w.exec();
+
+
+
+            SetupThisUi();
+            //this->centralWidget()->update();
+            //this->centralWidget()->repaint();
+
+          return true;
+        }
+     return false;
+    }
+#endif
+
+void MainWindow::SetupThisUi()
+{
+
+
+    QSettings oSettings("janbergmann", "simplenotewidget");
+    QColor cldefault = oSettings.value("bgcolor", QColor(255,255,0)).value<QColor>();
+    QColor cllabelcolor = oSettings.value("lblcolor", QColor(0,0,0)).value<QColor>();
+    QColor cltextedit = oSettings.value("txtcolor", QColor(0,0,0)).value<QColor>();
+    int bgcoloralpha = oSettings.value("bgcoloralpha", int(180)).toInt();
+    cldefault.setAlpha(bgcoloralpha);
+
+
+
+    QPalette pal = this->palette();
+    this->setAttribute(Qt::WA_TranslucentBackground);
+    this->setAttribute(Qt::WA_NoSystemBackground, false);
+
+    pal.setColor(QPalette::Window, cldefault);
+    this->setPalette(pal);
+    this->ensurePolished(); // workaround Oxygen filling the background
+    this->setAttribute(Qt::WA_StyledBackground, false);
+
 
 
 
@@ -153,6 +150,10 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->teMain->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     ui->teMain->setReadOnly(true);
 
+    ui->teMain->setStyleSheet( "background-color: rgba( 255, 255, 0, 0% );" );
+
+
+
     ui->lblDate->setLayoutDirection(Qt::RightToLeft);
     ui->lblDate->setPalette(QPalette(cllabelcolor,cllabelcolor,cllabelcolor,cllabelcolor,cllabelcolor,cllabelcolor,cldefault,cldefault,cldefault));
     ui->lblDate->setFont(QFont("Nokia Sans SemiBold",10,10));
@@ -165,15 +166,6 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->pbEdit->setFlat(true);
 
 
-
-
-
-
-    QDateTime dateTime = QDateTime::currentDateTime();
-    QString dateTimeString = dateTime.toString("dd.MM.yyyy   HH:mm");
-    ui->lblDate->setText(dateTimeString);
-
-
 #ifdef Q_WS_HILDON
        this->setProperty("FingerScrollable", true);
        this->setFocusPolicy(Qt::StrongFocus);
@@ -181,34 +173,16 @@ MainWindow::MainWindow(QWidget *parent) :
        ui->teMain->setProperty("FingerScrollable", true);
 #endif
 
+   ui->teMain->setText(oSettings.value("note","").toString());
+   ui->lblDate->setText(oSettings.value("notedate",QDateTime::currentDateTime().toString("dd.MM.yyyy   HH:mm")).toString());
 
+   ui->centralWidget->repaint();
+   this->repaint();
 
-
-
-    LoadItems();
 }
 
 
 
-
-
-
-
-#ifdef Q_WS_HILDON
-    //Filter show setting requests
-    bool QWidget::x11Event ( XEvent * event )
-    {
-        static Atom appletShowSettingAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_SHOW_SETTINGS", false);
-        if (event->xclient.message_type == appletShowSettingAtom )
-        {
-          QMessageBox::information(0, "Settings", "will implement this in a future release", QMessageBox::Ok);
-          return true;
-        }
-     return false;
-    }
-#endif
-
-
 MainWindow::~MainWindow()
 {
     delete ui;
@@ -231,7 +205,10 @@ void MainWindow::changeEvent(QEvent *e)
 
 void MainWindow::on_pbEdit_clicked()
 {
+    SetupThisUi();
     Dialog w(0);
     w.exec();
-    LoadItems();
+    QSettings oSettings("janbergmann", "simplenotewidget");
+    ui->teMain->setText(oSettings.value("note","").toString());
+    ui->lblDate->setText(oSettings.value("notedate",QDateTime::currentDateTime().toString("dd.MM.yyyy   HH:mm")).toString());
 }
